core/better_notifier library

Classes

VN<T>
A simplified and enhanced abstraction for working with ValueNotifier.

Enums

ChangeType
Specifies the behavior for updating the value of a VN.

Typedefs

ValueChanger<T> = void Function(T newValue)