BetterIterableNotifications<T> extension
Extension to provide additional methods for VN<Iterable<T>>.
Properties
- first → T
-
Available on VN<
Returns the first element in the iterable.Iterable< , provided by the BetterIterableNotifications extensionT> >no setter - firstOrNull → T?
-
Available on VN<
Returns the first element in the iterable, orIterable< , provided by the BetterIterableNotifications extensionT> >nullif the iterable is empty.no setter - isEmpty → bool
-
Available on VN<
ReturnsIterable< , provided by the BetterIterableNotifications extensionT> >trueif the iterable has no elements.no setter - isNotEmpty → bool
-
Available on VN<
ReturnsIterable< , provided by the BetterIterableNotifications extensionT> >trueif the iterable has one or more elements.no setter - last → T
-
Available on VN<
Returns the last element in the iterable.Iterable< , provided by the BetterIterableNotifications extensionT> >no setter - lastOrNull → T?
-
Available on VN<
Returns the last element in the iterable, orIterable< , provided by the BetterIterableNotifications extensionT> >nullif the iterable is empty.no setter - length → int
-
Available on VN<
Returns the number of elements in the iterable.Iterable< , provided by the BetterIterableNotifications extensionT> >no setter
Methods
-
firstWhere(
bool function(T)) → T -
Available on VN<
Returns the first element that satisfies the given predicateIterable< , provided by the BetterIterableNotifications extensionT> >function. -
lastWhere(
bool function(T)) → T -
Available on VN<
Returns the last element that satisfies the given predicateIterable< , provided by the BetterIterableNotifications extensionT> >function. -
toList(
) → List< T> -
Available on VN<
Returns a new list containing all elements of the iterable.Iterable< , provided by the BetterIterableNotifications extensionT> > -
where(
bool function(T)) → Iterable< T> -
Available on VN<
Returns a new lazy Iterable with all elements that satisfy the predicateIterable< , provided by the BetterIterableNotifications extensionT> >function.
Operators
-
operator [](
int index) → T -
Available on VN<
Gets the element at the specifiedIterable< , provided by the BetterIterableNotifications extensionT> >indexin the iterable.