firstWhere method
Returns the first element that satisfies the given predicate function.
Implementation
T firstWhere(bool Function(T) function) => value.firstWhere(function);
Returns the first element that satisfies the given predicate function.
T firstWhere(bool Function(T) function) => value.firstWhere(function);