lastWhere method
Returns the last element that satisfies the given predicate function.
Implementation
T lastWhere(bool Function(T) function) => value.lastWhere(function);
Returns the last element that satisfies the given predicate function.
T lastWhere(bool Function(T) function) => value.lastWhere(function);