operator [] method
Gets the element at the specified index in the iterable.
Implementation
T operator [](int index) {
return value.elementAt(index);
}
Gets the element at the specified index in the iterable.
T operator [](int index) {
return value.elementAt(index);
}