hardAddAll method
Appends all elements from the given iterable value to the list and notifies listeners.
value: The iterable containing elements to add.
Implementation
void hardAddAll(Iterable<T> value) {
this.value.addAll(value);
notify();
}
Appends all elements from the given iterable value to the list and notifies listeners.
value: The iterable containing elements to add.void hardAddAll(Iterable<T> value) {
this.value.addAll(value);
notify();
}