operator [] method
Gets the element at the specified index in the list.
index: The index of the element to retrieve.- Returns: The element at the specified
index.
Implementation
T operator [](int index) => value[index];
Gets the element at the specified index in the list.
index: The index of the element to retrieve.index.T operator [](int index) => value[index];