silentAdd method
void
silentAdd(
- T value
Adds the given value to the list without notifying listeners.
value: The value to add to the list.
Implementation
void silentAdd(T value) => this.value.add(value);
Adds the given value to the list without notifying listeners.
value: The value to add to the list.void silentAdd(T value) => this.value.add(value);