smartAddAll method
Appends all elements from the given iterable value to the list, with behavior determined by ChangeType.
value: The iterable containing elements to add.
Implementation
void smartAddAll(Iterable<T> value) => hardAddAll(value);
Appends all elements from the given iterable value to the list, with behavior determined by ChangeType.
value: The iterable containing elements to add.void smartAddAll(Iterable<T> value) => hardAddAll(value);