hardRemove method

V? hardRemove(
  1. K key
)

Removes the key-value pair with the given key from the map and notifies listeners.

  • key: The key of the element to remove.
  • Returns: The value associated with the key, or null if the key was not present.

Implementation

V? hardRemove(K key) {
  final removedValue = value.remove(key);
  notify();
  return removedValue;
}