hardRemoveWhere method

void hardRemoveWhere(
  1. bool where(
    1. K key,
    2. V value
    )
)

Removes all key-value pairs from the map that satisfy the predicate where and notifies listeners.

  • where: A function that returns true for elements to remove.

Implementation

void hardRemoveWhere(bool Function(K key, V value) where) {
  value.removeWhere(where);
  notify();
}