isNotEmpty property
bool
get
isNotEmpty
Returns true if the map has one or more key-value pairs.
Implementation
bool get isNotEmpty => value.isNotEmpty;
Returns true if the map has one or more key-value pairs.
bool get isNotEmpty => value.isNotEmpty;