operator [] method

V? operator [](
  1. K key
)

Retrieves the value associated with the given key in the map.

  • key: The key of the element to retrieve.
  • Returns: The value associated with the key, or null if the key is not present.

Implementation

V? operator [](K key) {
  return value[key];
}