remove method

V? remove(
  1. K key
)

Removes the key-value pair with the given key from the map.

  • key: The key of the element to remove.
  • Returns: The value associated with the key, or null if the key was not present.

The update behavior is determined by the ChangeType of the VN.

Implementation

V? remove(K key) => switch (changeType) {
      ChangeType.hard => hardRemove(key),
      ChangeType.silent => silentRemove(key),
      ChangeType.smart => smartRemove(key),
    };