removeWhere method

void removeWhere(
  1. bool where(
    1. K key,
    2. V value
    )
)

Removes all key-value pairs from the map that satisfy the given predicate where.

  • where: A function that returns true for elements to remove.

Implementation

void removeWhere(bool Function(K key, V value) where) {
  switch (changeType) {
    case ChangeType.hard:
      hardRemoveWhere(where);
      break;
    case ChangeType.silent:
      silentRemoveWhere(where);
      break;
    case ChangeType.smart:
      smartRemoveWhere(where);
      break;
  }
}