silentRemove method

V? silentRemove(
  1. K key
)

Removes the key-value pair with the given key from the map without notifying listeners.

  • key: The key of the element to remove.
  • Returns: The value associated with the key, or null if the key was not present.

Implementation

V? silentRemove(K key) => value.remove(key);