silentRemoveWhere method

void silentRemoveWhere(
  1. bool where(
    1. K key,
    2. V value
    )
)

Removes all key-value pairs from the map that satisfy the predicate where without notifying listeners.

  • where: A function that returns true for elements to remove.

Implementation

void silentRemoveWhere(bool Function(K key, V value) where) {
  value.removeWhere(where);
}