smartClear method
void
smartClear()
Removes all key-value pairs from the map, with behavior determined by ChangeType.
Implementation
void smartClear() {
if (value.isNotEmpty) {
value.clear();
notify();
}
}
Removes all key-value pairs from the map, with behavior determined by ChangeType.
void smartClear() {
if (value.isNotEmpty) {
value.clear();
notify();
}
}