smartRemoveWhere method

void smartRemoveWhere(
  1. bool where(
    1. K key,
    2. V value
    )
)

Removes all key-value pairs from the map that satisfy the predicate where, with behavior determined by ChangeType.

  • where: A function that returns true for elements to remove.

Implementation

void smartRemoveWhere(bool Function(K key, V value) where) {
  final originalLength = value.length;
  value.removeWhere(where);
  if (value.length != originalLength) {
    notify();
  }
}