hardClear method
void
hardClear()
Removes all elements from the set and notifies listeners.
Implementation
void hardClear() {
value.clear();
notify();
}
Removes all elements from the set and notifies listeners.
void hardClear() {
value.clear();
notify();
}