hardRemoveWhere method

void hardRemoveWhere(
  1. bool where(
    1. T
    )
)

Removes all elements from the set that satisfy the predicate where and notifies listeners.

  • where: A function that returns true for elements to remove.

Implementation

void hardRemoveWhere(bool Function(T) where) {
  value.removeWhere(where);
  notify();
}