isNotEmpty property
bool
get
isNotEmpty
Returns true if the set has one or more elements.
Implementation
bool get isNotEmpty => value.isNotEmpty;
Returns true if the set has one or more elements.
bool get isNotEmpty => value.isNotEmpty;