map<R> method
Transforms the set by applying a function to all its elements.
map: A function that transforms each element of the set.- Returns: A lazy iterable of transformed elements.
Implementation
Iterable<R> map<R>(R Function(T e) map) => value.map(map);