operator [] method
Retrieves the element at the specified index in the set.
index: The index of the element to retrieve.- Returns: The element at the specified
index.
Implementation
T operator [](int index) => value.elementAt(index);
Retrieves the element at the specified index in the set.
index: The index of the element to retrieve.index.T operator [](int index) => value.elementAt(index);