silentAdd method
Adds the given value to the set without notifying listeners.
value: The element to add to the set.- Returns:
trueif the value was added,falseotherwise.
Implementation
bool silentAdd(T value) => this.value.add(value);
Adds the given value to the set without notifying listeners.
value: The element to add to the set.true if the value was added, false otherwise.bool silentAdd(T value) => this.value.add(value);