silentRemoveWhere method

void silentRemoveWhere(
  1. bool where(
    1. T
    )
)

Removes all elements from the set that satisfy the predicate where without notifying listeners.

  • where: A function that returns true for elements to remove.

Implementation

void silentRemoveWhere(bool Function(T) where) {
  value.removeWhere(where);
}