smartClear method
void
smartClear()
Removes all elements from the set and notifies listeners if the set was not empty.
Implementation
void smartClear() {
if (value.isNotEmpty) {
value.clear();
notify();
}
}
Removes all elements from the set and notifies listeners if the set was not empty.
void smartClear() {
if (value.isNotEmpty) {
value.clear();
notify();
}
}