smartRemoveWhere method

void smartRemoveWhere(
  1. bool where(
    1. T
    )
)

Removes all elements from the set that satisfy the predicate where, with behavior determined by ChangeType.

  • where: A function that returns true for elements to remove.

Implementation

void smartRemoveWhere(bool Function(T) where) {
  final originalLength = value.length;
  value.removeWhere(where);
  if (value.length != originalLength) {
    notify();
  }
}