where method

Iterable<T> where(
  1. bool function(
    1. T function
    )
)

Returns a new lazy Iterable with all elements that satisfy the predicate function.

  • function: A function that returns true for elements to include.
  • Returns: A lazy iterable of matching elements.

Implementation

Iterable<T> where(bool Function(T function) function) =>
    value.where(function);