map<R> method

Iterable<R> map<R>(
  1. R map(
    1. T e
    )
)

Transforms the set by applying a function to all its elements.

  • map: A function that transforms each element of the set.
  • Returns: A lazy iterable of transformed elements.

Implementation

Iterable<R> map<R>(R Function(T e) map) => value.map(map);